==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/city/dialogs_nl.lua <==

dialogId("vit-hs-vitejteA", "font_statue", "Welcome to the most beautiful city under the sun.")
dialogStr("Welkom in de mooiste stad onder de zon.")


dialogId("vit-hs-vitejteB", "font_statue", "Welcome to our city - the city of unlimited opportunities.")
dialogStr("Welkom in onze stad - de stad van onbeperkte mogelijkheden.")


dialogId("vit-hs-vitejteC", "font_statue", "On behalf of the citizens of this town I welcome you.")
dialogStr("In naam van de burgers van deze stad heet ik u welkom.")


dialogId("vit-hs-vitejteD", "font_statue", "Welcome to our city, whose beauty eclipses that of the gods themselves.")
dialogStr("Welkom in onze stad.  Vergeleke bij haar schoonheid verbleekt zelfs de schoonheid van de goden zelf.")


dialogId("vit-hs-klid1", "font_statue", "Citizens, please remain calm.")
dialogStr("Waarde burgers, blijft alstublieft rustig.")


dialogId("vit-hs-klid2", "font_statue", "There is no imminent danger.")
dialogStr("Er is geen direct gevaar.")


dialogId("vit-hs-klid3", "font_statue", "The sinking of the northern part of our island is only temporary.")
dialogStr("De overstroming van het noordelijke gedeelte van ons eiland is slechts tijdelijk.")


dialogId("vit-hs-klid4", "font_statue", "We have the situation completely under control.")
dialogStr("We hebben de situatie volledig onder controle.")


dialogId("vit-hs-lod0", "font_statue", "The ship from Lemury has now docked at pier #5. This ship continues on to Utopia, Mu and Atlantis.")
dialogStr("Het schip Lemurie heeft zojuist aangelegd bij steiger 5. Dit schip gaat verder naar Utopia, Mu en Atlantis.")


dialogId("vit-hs-pojis0", "font_statue", "With First Fishermen Insurance, your house is covered against damage caused by fire, tornadoes, hurricanes, acts of God and dragons` raids. Because fishermen think of everything, choose First Fisherman.")
dialogStr("Met een Vissers Verzekering is uw huis verzekerd tegen schade als gevolg van brand, tornado's, wervelwinden, goddelijk interventie en drakenaanvallen. Omdat vissers overal aan denken, verzeker uw huis bij Vissers.")


dialogId("vit-hs-reklama1", "font_statue", "Where are you running?")
dialogStr("Waar heb je zo'n haast?")


dialogId("vit-hs-reklama2", "font_white", "To Moon Street. I need to order eight swords.")
dialogStr("Ik ga naar Maanstraat. Ik moet acht zwaarden bestellen.")


dialogId("vit-hs-reklama3", "font_statue", "Why so many swords?")
dialogStr("Waarom zoveel zwaarden?")


dialogId("vit-hs-reklama4", "font_white", "You haven`t heard?!? For every eight swords you purchase, you get a pair of bronze earrings absolutely FREE!")
dialogStr("Heb je het niet gehoord? Bij elke acht zwaarden krijg je helemaal GRATIS een paar bronzen oorbellen!")


dialogId("vit-hs-reklama5", "font_statue", "Wait for me. I`m coming with you!")
dialogStr("Wacht op mij. Ik ga mee!")


dialogId("vit-hs-soud0", "font_statue", "The City Court kindly invites you to the annual town festival of interrogations and executions. Proper attire required.")
dialogStr("Het Gerechtshof van de stad nodigt u allen uit voor het jaarlijkse festival van ondervragingen en executies. Avondkleding verplicht.")


dialogId("vit-hs-vodovod0", "font_statue", "The City Council has decided to build an aqueduct, thereby providing direct water service to each home.")
dialogStr("De gemeenteraad heeft besloten een aquaduct te bouwen om direct stromend water naar elk huis mogelijk te maken.")


dialogId("vit-hs-dite0", "font_statue", "Would the mother of the child who got lost on the grounds of city treasury please come to the front desk to pick up his remains.")
dialogStr("Zou de moeder van het kind dat verdwaald was in de stadsschatkamer alstublieft zijn overschot kunnen ophalen bij de receptie.")


dialogId("vit-hs-demoni0", "font_statue", "Citizens, our employees will be stopping by individual homes tomorrow after midnight in order to rid your home of demons and ghosts. We ask that you kindly let them in.")
dialogStr("Geëerde burgers, onze werknemers komen morgen na middennacht bij alle huizen langs om demonen en geesten uit te drijven. We vragen vriendelijk om uw medewerking.")


dialogId("vit-hs-kacir", "font_statue", "Our chief heretic Demikuls will present a lecture this evening in the small auditorium entitled `Do the gods really exist? or Rest assured they cannot harm you!`")
dialogStr("Onze hoofdketter Demikuls zal vanavond in het kleine auditorium een seminarium geven getiteld `Bestaan de goden echt? of Wees gerust dat ze u geen kwaad kunnen doen!'")


dialogId("vit-hs-jidelna1", "font_statue", "Come visit our seafood restaurant located at the Main Square. Delicious fish specialties and...")
dialogStr("Bezoek ons visrestaurant aan het Marktplein. Heerlijke visspecialiteiten en...")


dialogId("vit-hs-jidelna2", "font_statue", "Oh, excuse me.")
dialogStr("O, pardon.")


dialogId("vit-m-jakze", "font_small", "What?! A fish restaurant?")
dialogStr("Wat?! Een visrestaurant?")


dialogId("vit-v-vazne", "font_big", "Are you serious?")
dialogStr("Meent u dat nou echt?")


dialogId("vit-m-nechutne", "font_small", "How disgusting!")
dialogStr("Wat afgrijselijk!")


dialogId("vit-v-nevsimla", "font_big", "That sculpture obviously hasn`t noticed that the city sank a long time ago.")
dialogStr("Dit beeld heeft duidelijk niet door dat de stad een hele tijd geleden verzonken is.")


dialogId("vit-v-automat", "font_big", "It`s probably some kind of automaton. It still thinks that the city is alive.")
dialogStr("Het is waarschijnlijk automatisch ofzo. Het denkt dat de stad nog leeft.")


dialogId("vit-m-nebo", "font_small", "Or it just can`t face the truth.")
dialogStr("Of het kan de waarheid niet aan.")


dialogId("vit-m-hlava", "font_small", "I`m getting a headache from that head.")
dialogStr("Ik krijg hoofdpijn van dat hoofd.")


dialogId("vit-v-hlava", "font_big", "That head is giving me a headache.")
dialogStr("Dat hoofd doet mijn hoofd pijn.")


dialogId("vit-m-nezkusime", "font_small", "Let`s try to shut that head up somehow.")
dialogStr("Laten we proberen dat hoofd het zwijgen op te leggen.")


dialogId("vit-v-proc", "font_big", "Why? We`re getting invaluable information about the everyday life of our ancestors.")
dialogStr("Hoezo? We krijgen allemaal waardevolle informatie over het dagelijkse leven van onze voorouders.")


dialogId("vit-v-krabi", "font_big", "If we could get all these crabs up near the head...")
dialogStr("Als we al deze krabben daarboven bij dat hoofd konden krijgen...")


dialogId("vit-m-tak", "font_small", "...then...?")
dialogStr("...dan...?")


dialogId("vit-v-pockej", "font_big", "Wait, I have to think about it for a moment...")
dialogStr("Wacht, ik moet nog even nadenken...")


dialogId("vit-m-vecnost", "font_small", "Just imagine - that head has been like doing this all these years...")
dialogStr("Stel je voor - dat hoofd is al die tijd zo bezig geweest...")


dialogId("vit-v-noa", "font_big", "So what?")
dialogStr("Nou en?")


dialogId("vit-m-jak", "font_small", "Well think about how these poor crabs must feel!")
dialogStr("Moet je je eens voorstellen hoe die arme krabben zich voelen!")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/city/dialogs_nl.lua <==

dialogId("vit-hs-vitejteA", "font_statue", "Welcome to the most beautiful city under the sun.")
dialogStr("Welkom in de mooiste stad onder de zon.")


dialogId("vit-hs-vitejteB", "font_statue", "Welcome to our city - the city of unlimited opportunities.")
dialogStr("Welkom in onze stad - de stad van onbeperkte mogelijkheden.")


dialogId("vit-hs-vitejteC", "font_statue", "On behalf of the citizens of this town I welcome you.")
dialogStr("In naam van de burgers van deze stad heet ik u welkom.")


dialogId("vit-hs-vitejteD", "font_statue", "Welcome to our city, whose beauty eclipses that of the gods themselves.")
dialogStr("Welkom in onze stad.  Vergeleke bij haar schoonheid verbleekt zelfs de schoonheid van de goden zelf.")


dialogId("vit-hs-klid1", "font_statue", "Citizens, please remain calm.")
dialogStr("Waarde burgers, blijft alstublieft rustig.")


dialogId("vit-hs-klid2", "font_statue", "There is no imminent danger.")
dialogStr("Er is geen direct gevaar.")


dialogId("vit-hs-klid3", "font_statue", "The sinking of the northern part of our island is only temporary.")
dialogStr("De overstroming van het noordelijke gedeelte van ons eiland is slechts tijdelijk.")


dialogId("vit-hs-klid4", "font_statue", "We have the situation completely under control.")
dialogStr("We hebben de situatie volledig onder controle.")


dialogId("vit-hs-lod0", "font_statue", "The ship from Lemury has now docked at pier #5. This ship continues on to Utopia, Mu and Atlantis.")
dialogStr("Het schip uit Lemuria heeft zojuist aangelegd bij steiger 5. Dit schip gaat verder naar Utopia, Mu en Atlantis.")


dialogId("vit-hs-pojis0", "font_statue", "With First Fishermen Insurance, your house is covered against damage caused by fire, tornadoes, hurricanes, acts of God and dragons’ raids. Because fishermen think of everything, choose First Fisherman.")
dialogStr("Met een Vissers Verzekering is uw huis verzekerd tegen schade als gevolg van brand, tornado's, wervelwinden, goddelijk interventie en drakenaanvallen. Omdat vissers overal aan denken, verzeker uw huis bij Vissers.")


dialogId("vit-hs-reklama1", "font_statue", "Where are you running?")
dialogStr("Waarom heb je zo'n haast?")


dialogId("vit-hs-reklama2", "font_white", "To Moon Street. I need to order eight swords.")
dialogStr("Ik ga naar Maanstraat. Ik moet acht zwaarden bestellen.")


dialogId("vit-hs-reklama3", "font_statue", "Why so many swords?")
dialogStr("Waarom zoveel zwaarden?")


dialogId("vit-hs-reklama4", "font_white", "You haven’t heard?!? For every eight swords you purchase, you get a pair of bronze earrings absolutely FREE!")
dialogStr("Heb je het niet gehoord? Bij elke acht zwaarden krijg je helemaal GRATIS een paar bronzen oorbellen!")


dialogId("vit-hs-reklama5", "font_statue", "Wait for me. I’m coming with you!")
dialogStr("Wacht op mij. Ik ga mee!")


dialogId("vit-hs-soud0", "font_statue", "The City Court kindly invites you to the annual town festival of interrogations and executions. Proper attire required.")
dialogStr("Het Gerechtshof van de stad nodigt u allen uit voor het jaarlijkse festival van ondervragingen en executies. Gepaste kleding verplicht.")


dialogId("vit-hs-vodovod0", "font_statue", "The City Council has decided to build an aqueduct, thereby providing direct water service to each home.")
dialogStr("De gemeenteraad heeft besloten een aquaduct te bouwen om direct stromend water naar elk huis mogelijk te maken.")


dialogId("vit-hs-dite0", "font_statue", "Would the mother of the child who got lost on the grounds of city treasury please come to the front desk to pick up his remains.")
dialogStr("Zou de moeder van het kind dat verdwaald was in de stadsschatkamer alstublieft zijn stoffelijk overschot kunnen ophalen bij de receptie.")


dialogId("vit-hs-demoni0", "font_statue", "Citizens, our employees will be stopping by individual homes tomorrow after midnight in order to rid your home of demons and ghosts. We ask that you kindly let them in.")
dialogStr("Waarde burgers, onze werknemers komen morgen na middennacht bij alle huizen langs om demonen en geesten uit te drijven. We vragen vriendelijk om uw medewerking.")


dialogId("vit-hs-kacir", "font_statue", "Our chief heretic Demikuls will present a lecture this evening in the small auditorium entitled ’Do the gods really exist? or Rest assured they cannot harm you!’")
dialogStr("Onze hoofdketter Demikuls zal vanavond in het kleine auditorium een seminarium geven getiteld \"Bestaan de goden echt? of Wees gerust dat ze u geen kwaad kunnen doen!\"")


dialogId("vit-hs-jidelna1", "font_statue", "Come visit our seafood restaurant located at the Main Square. Delicious fish specialties and...")
dialogStr("Bezoek ons visrestaurant aan het Marktplein. Heerlijke visspecialiteiten en...")


dialogId("vit-hs-jidelna2", "font_statue", "Oh, excuse me.")
dialogStr("O, pardon.")


dialogId("vit-m-jakze", "font_small", "What?! A fish restaurant?")
dialogStr("Wat?! Een visrestaurant?")


dialogId("vit-v-vazne", "font_big", "Are you serious?")
dialogStr("Meen je dat nou echt?")


dialogId("vit-m-nechutne", "font_small", "How disgusting!")
dialogStr("Wat afgrijselijk!")


dialogId("vit-v-nevsimla", "font_big", "That sculpture obviously hasn’t noticed that the city sank a long time ago.")
dialogStr("Dit beeld heeft duidelijk niet door dat de stad al een hele tijd geleden onderwater gelopen is.")


dialogId("vit-v-automat", "font_big", "It’s probably some kind of automaton. It still thinks that the city is alive.")
dialogStr("Het is waarschijnlijk geautomatiseerd ofzo. Het denkt dat de stad nog leeft.")


dialogId("vit-m-nebo", "font_small", "Or it just can’t face the truth.")
dialogStr("Of het kan de waarheid niet aan.")


dialogId("vit-m-hlava", "font_small", "I’m getting a headache from that head.")
dialogStr("Ik krijg hoofdpijn van dat hoofd.")


dialogId("vit-v-hlava", "font_big", "That head is giving me a headache.")
dialogStr("Dat hoofd doet mijn hoofd pijn.")


dialogId("vit-m-nezkusime", "font_small", "Let’s try to shut that head up somehow.")
dialogStr("Laten we proberen dat hoofd het zwijgen op te leggen.")


dialogId("vit-v-proc", "font_big", "Why? We’re getting invaluable information about the everyday life of our ancestors.")
dialogStr("Hoezo? We krijgen allemaal waardevolle informatie over het dagelijkse leven van onze voorouders.")


dialogId("vit-v-krabi", "font_big", "If we could get all these crabs up near the head...")
dialogStr("Als we al deze krabben daarboven bij dat hoofd konden krijgen...")


dialogId("vit-m-tak", "font_small", "...then...?")
dialogStr("...dan...?")


dialogId("vit-v-pockej", "font_big", "Wait, I have to think about it for a moment...")
dialogStr("Wacht, ik moet nog even nadenken...")


dialogId("vit-m-vecnost", "font_small", "Just imagine - that head has been like doing this all these years...")
dialogStr("Stel je voor - dat hoofd is al die tijd zo bezig geweest...")


dialogId("vit-v-noa", "font_big", "So what?")
dialogStr("Nou en?")


dialogId("vit-m-jak", "font_small", "Well think about how these poor crabs must feel!")
dialogStr("Moet je je eens voorstellen hoe die arme krabben zich voelen!")
